@@ -1,4 +1,5 @@
 #!/usr/bin/perl
+################################################################################
 
 ### Scenario 1: Extending an Object with Module Methods
 
@@ -19,6 +20,8 @@
         print "$key: ", $self->{$key} // 'undefined', "\n";
     }
 
+    ############################################################################
+
     package MyObject;
 
     sub new {
@@ -27,6 +30,8 @@
         return $self;
     }
 
+    ############################################################################
+
     package main;
 
     use strict;
@@ -57,6 +62,8 @@
         return $self;
     }
 
+    ############################################################################
+
     package main;
 
     use Extender;
@@ -94,6 +101,8 @@
         print "Value: $$self\n";
     }
 
+    ############################################################################
+
     package MyClass1;
 
     sub new {
@@ -102,6 +111,8 @@
         return $self;
     }
 
+    ############################################################################
+
     package MyClass2;
 
     sub new {
@@ -110,6 +121,8 @@
         return $self;
     }
 
+    ############################################################################
+
     package main;
 
     use strict;
@@ -143,6 +156,8 @@
 
 ### Scenario 4: Adding Methods to Raw References (Hash, Array, Scalar)
 
+    ############################################################################
+
     # PACKAGES
 
     package HashMethods;
@@ -164,6 +179,8 @@
 
     1;
 
+    ############################################################################
+
     package ArrayMethods;
 
     use strict;
@@ -183,6 +200,8 @@
 
     1;
 
+    ############################################################################
+
     package ScalarMethods;
 
     use strict;
@@ -212,6 +231,8 @@
 
     1;
 
+    ############################################################################
+
     # MAIN 
 
     package main;
@@ -284,6 +305,8 @@
 
     # Example methods to manipulate shared data
 
+    ############################################################################
+
     # Method to set data in a shared hash
     sub set_hash_data {
         my ($self, $key, $value) = @_;
@@ -298,6 +321,8 @@
         return $self->{$key};
     }
 
+    ############################################################################
+
     # Method to add item to a shared array
     sub add_array_item {
         my ($self, $item) = @_;
@@ -312,6 +337,8 @@
         return $self->[$index];
     }
 
+    ############################################################################
+
     # Method to set data in a shared scalar
     sub set_scalar_data {
         my ($self, $value) = @_;
@@ -326,6 +353,8 @@
         return ${$self};
     }
 
+    ############################################################################
+
     # Create shared data structures
     my %shared_hash :shared;
     my @shared_array :shared;
@@ -336,6 +365,8 @@
     my $shared_array_object = \@shared_array;
     my $shared_scalar_object = \$shared_scalar;
 
+    ############################################################################
+
     # Extend the shared hash object with custom methods
     Extends($shared_hash_object,
         set_hash_data => \&set_hash_data,
@@ -354,6 +385,8 @@
         get_scalar_data => \&get_scalar_data,
     );
 
+    ############################################################################
+
     # Create threads to manipulate shared objects concurrently
 
     # Thread for shared hash object
@@ -374,6 +407,8 @@
         print "Scalar thread: value = " . $shared_scalar_object->get_scalar_data() . "\n";
     });
 
+    ############################################################################
+
     # Wait for all threads to finish
     $hash_thread->join();
     $array_thread->join();
@@ -395,6 +430,8 @@
         return "Original method";
     }
 
+    ############################################################################
+
     package main;
 
     use Extender;
@@ -427,6 +464,8 @@
         return "Method 2";
     }
 
+    ############################################################################
+
     package main;
 
     use Extender;
@@ -462,6 +501,8 @@
         return $self;
     }
 
+    ############################################################################
+
     package main;
 
     use Extender;
@@ -490,6 +531,8 @@
         return "Original method";
     }
 
+    ############################################################################
+
     package main;
 
     use Extender;
@@ -517,6 +560,8 @@
         *{$object . "::new_method"} = sub { return "New method"; };
     }
 
+    ############################################################################
+
     package MyClass;
 
     sub new {
@@ -525,6 +570,8 @@
         return $self;
     }
 
+    ############################################################################
+
     package main;
 
     use Extender;
@@ -543,17 +590,17 @@
 
     package TestObject;
 
-    sub new {
-        my $self = bless {}, shift;
-        return $self;
-    }
+    sub new { return bless {}, shift }
 
     sub DESTROY {
         my $self = shift;
         # Implement destruction logic if needed
     }
 
+    ############################################################################
+
     package main;
+
     use Extender;
 
     InitHook('TestObject', 'INIT', sub {
