@@ -88,6 +88,14 @@ This function extends the specified C<$object> by importing methods from the mod
 
     ############################################################################
 
+=head3 Supported Object Types: Can be applied to HASH, ARRAY, SCALAR, GLOB references, or a complete class object. For example:
+
+    my $hash_ref = Extend({}, 'HashMethods', 'method1', 'method2');
+    my $array_ref = Extend([], 'ArrayMethods', 'method1', 'method2');
+    my $scalar_ref = Extend(\(my $scalar = 'value'), 'ScalarMethods', 'method1');
+    my $glob_ref = Extend(\*GLOB, 'GlobMethods', 'method1');
+    my $class_ref = Extend(MyClass->new(), 'ClassMethods', 'method1');
+
 =cut
 
 sub Extend {
@@ -147,6 +155,17 @@ This function extends the specified C<$object> by adding custom methods defined
 
     ############################################################################
 
+=head3 Supported Object Types: Can be used with HASH, ARRAY, SCALAR, GLOB references, or class objects. For example:
+
+     Extends($hash_object, hash_method => sub { ... });
+     Extends($array_object, array_method => sub { ... });
+     Extends($scalar_object, scalar_method => sub { ... });
+     Extends($glob_object, glob_method => sub { ... });
+     Extends($hash_class, hash_method => sub { ... });
+     Extends($array_class, array_method => sub { ... });
+     Extends($scalar_class, scalar_method => sub { ... });
+     Extends($glob_class, glob_method => sub { ... });
+
 =cut
 
 sub Extends {
@@ -211,6 +230,8 @@ This function creates an alias for an existing method in the object with a new n
 
     ############################################################################
 
+=head3 Supported Object Types: Can be used with HASH, ARRAY, SCALAR, GLOB references, or class objects.
+
 =cut
 
 sub Alias {
@@ -278,6 +299,8 @@ This function adds a new method to the object's namespace. It validates the meth
 
     ############################################################################
 
+=head3 Supported Object Types: Can be used with HASH, ARRAY, SCALAR, GLOB references, or class objects.
+
 =cut
 
 sub AddMethod {
@@ -349,6 +372,8 @@ This function allows decorating an existing method of an object with a custom de
 
 =cut
 
+=head3 Supported Object Types: Can be used with HASH, ARRAY, SCALAR, GLOB references, or class objects.
+
 sub Decorate {
     my ($object, $method_name, $decorator) = @_;
 
@@ -443,9 +468,12 @@ This function loads a role class using C<require>, imports its methods into the
 
     ############################################################################
 
+=head3 Supported Object Types: Can be used with HASH, ARRAY, SCALAR, GLOB references, or class objects.
+
 =cut
 
 sub ApplyRole {
+
     my ($object, $role_class) = @_;
 
     die "Object must be provided for role application" unless defined $object;
@@ -536,9 +564,15 @@ This function adds a code reference to the specified hook array (`_init_hooks` o
 
     ############################################################################
 
+=head3 Supported Object Types: Can only be used on class names. For example:
+
+    use ClassName;
+
+    InitHook('ClassName', 'INIT', sub { print "Hash object initialized\n" });
+    InitHook('ClassName', 'DESTRUCT', sub { print "Array object destructed\n" });
+
 =cut
 
-    
 sub InitHook {
     my ($class, $hook_name, $hook_code) = @_;
 
@@ -629,6 +663,8 @@ It effectively unloads or deletes methods that were previously added or defined
 
 =cut
 
+=head3 Supported Object Types: Can be used with HASH, ARRAY, SCALAR, GLOB references, or class objects.
+
 sub Unload {
     my ($object, @methods) = @_;
 
